# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List
from ..protobufs import main_pb2


class MovementFailedExceptionData:
    """
    Contains additional data for MovementFailedException.
    """

    @property
    def warnings(self) -> List[str]:
        """
        The full list of warnings.
        """

        return self._warnings

    @warnings.setter
    def warnings(self, value: List[str]) -> None:
        self._warnings = value

    @property
    def reason(self) -> str:
        """
        The reason for the Exception.
        """

        return self._reason

    @reason.setter
    def reason(self, value: str) -> None:
        self._reason = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.MovementFailedExceptionData
    ) -> 'MovementFailedExceptionData':
        instance = MovementFailedExceptionData.__new__(
            MovementFailedExceptionData
        )  # type: MovementFailedExceptionData
        instance.warnings = list(pb_data.warnings)
        instance.reason = pb_data.reason
        return instance



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
from enum import Enum


class StreamAxisType(Enum):
    """
    Denotes type of the stream axis.
    """

    PHYSICAL = 0
    LOCKSTEP = 1



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from .binary_command_failed_exception import BinaryCommandFailedException
from .command_failed_exception import CommandFailedException
from .command_preempted_exception import CommandPreemptedException
from .connection_closed_exception import ConnectionClosedException
from .connection_failed_exception import ConnectionFailedException
from .conversion_failed_exception import ConversionFailedException
from .device_address_conflict_exception import DeviceAddressConflictException
from .device_busy_exception import DeviceBusyException
from .device_db_failed_exception import DeviceDbFailedException
from .device_failed_exception import DeviceFailedException
from .device_not_identified_exception import DeviceNotIdentifiedException
from .internal_error_exception import InternalErrorException
from .invalid_argument_exception import InvalidArgumentException
from .invalid_data_exception import InvalidDataException
from .invalid_packet_exception import InvalidPacketException
from .invalid_park_state_exception import InvalidParkStateException
from .invalid_response_exception import InvalidResponseException
from .io_channel_out_of_range_exception import IoChannelOutOfRangeException
from .io_failed_exception import IoFailedException
from .lockstep_enabled_exception import LockstepEnabledException
from .lockstep_not_enabled_exception import LockstepNotEnabledException
from .movement_failed_exception import MovementFailedException
from .movement_interrupted_exception import MovementInterruptedException
from .no_device_found_exception import NoDeviceFoundException
from .not_supported_exception import NotSupportedException
from .os_failed_exception import OsFailedException
from .out_of_request_ids_exception import OutOfRequestIdsException
from .request_timeout_exception import RequestTimeoutException
from .serial_port_busy_exception import SerialPortBusyException
from .setting_not_found_exception import SettingNotFoundException
from .stream_execution_exception import StreamExecutionException
from .stream_mode_exception import StreamModeException
from .stream_movement_failed_exception import StreamMovementFailedException
from .stream_movement_interrupted_exception import StreamMovementInterruptedException
from .stream_setup_failed_exception import StreamSetupFailedException
from .unknown_request_exception import UnknownRequestException
from .motion_lib_exception import MotionLibException

from .binary_command_failed_exception_data import BinaryCommandFailedExceptionData
from .command_failed_exception_data import CommandFailedExceptionData
from .device_address_conflict_exception_data import DeviceAddressConflictExceptionData
from .invalid_packet_exception_data import InvalidPacketExceptionData
from .invalid_response_exception_data import InvalidResponseExceptionData
from .movement_failed_exception_data import MovementFailedExceptionData
from .movement_interrupted_exception_data import MovementInterruptedExceptionData
from .stream_execution_exception_data import StreamExecutionExceptionData
from .stream_movement_failed_exception_data import StreamMovementFailedExceptionData
from .stream_movement_interrupted_exception_data import StreamMovementInterruptedExceptionData



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from ..protobufs import main_pb2


class UnknownResponseEvent:
    """
    Reply that could not be matched to a request.
    """

    @property
    def device_address(self) -> int:
        """
        Number of the device that sent or should receive the message.
        """

        return self._device_address

    @device_address.setter
    def device_address(self, value: int) -> None:
        self._device_address = value

    @property
    def command(self) -> int:
        """
        The warning flag contains the highest priority warning currently active for the device or axis.
        """

        return self._command

    @command.setter
    def command(self, value: int) -> None:
        self._command = value

    @property
    def data(self) -> int:
        """
        Data payload of the message, if applicable, or zero otherwise.
        """

        return self._data

    @data.setter
    def data(self, value: int) -> None:
        self._data = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.UnknownBinaryResponseEvent
    ) -> 'UnknownResponseEvent':
        instance = UnknownResponseEvent.__new__(
            UnknownResponseEvent
        )  # type: UnknownResponseEvent
        instance.device_address = pb_data.device_address
        instance.command = pb_data.command
        instance.data = pb_data.data
        return instance
